@@ -22,8 +22,8 @@
 #include <string.h>
 #include <stddef.h>
 #include <errno.h>
+#include <stdbool.h>
 
-#include "dfu-bool.h"
 #include "dfu-device.h"
 #include "config.h"
 #include "arguments.h"
@@ -86,14 +86,14 @@ static inline void print_progress( intel_buffer_info_t *info,
    */
 
 static int32_t stm32_erase( dfu_device_t *device, uint8_t *command,
-                            uint8_t command_length, dfu_bool quiet );
+                            uint8_t command_length, bool quiet );
   /* erase, erase page, and read unprotect all share this functionality
    * although with different commands
    */
 
 
 //___ V A R I A B L E S ______________________________________________________
-extern int debug;       /* defined in main.c */
+extern int debug;       /* defined in libdfu.c */
 
 /* FIXME : these should be read from usb device descriptor because they are
  * device specific */
@@ -154,7 +154,7 @@ static int32_t stm32_set_address_ptr( dfu_device_t *device, uint32_t address ) {
     return -1;
   }
 
-  dfu_set_transaction_num( 0 );     /* set wValue to zero */
+  dfu_set_transaction_num( device, 0 );     /* set wValue to zero */
   if( length != dfu_download(device, length, command) ) {
     DEBUG( "dfu_download failed\n" );
     return -2;
@@ -272,9 +272,9 @@ static inline void print_progress( intel_buffer_info_t *info,
 }
 
 static int32_t stm32_erase( dfu_device_t *device, uint8_t *command,
-                            uint8_t command_length, dfu_bool quiet ) {
+                            uint8_t command_length, bool quiet ) {
   int32_t status;
-  dfu_set_transaction_num( 0 );     /* set wValue to zero */
+  dfu_set_transaction_num( device, 0 );     /* set wValue to zero */
   if( command_length != dfu_download(device, command_length, command) ) {
     if( !quiet ) fprintf( stderr, "ERROR\n" );
     DEBUG( "dfu_download failed\n" );
@@ -301,7 +301,7 @@ static int32_t stm32_erase( dfu_device_t *device, uint8_t *command,
 }
 
 //___ F U N C T I O N S ______________________________________________________
-int32_t stm32_erase_flash( dfu_device_t *device, dfu_bool quiet ) {
+int32_t stm32_erase_flash( dfu_device_t *device, bool quiet ) {
   TRACE( "%s( %p, %s )\n", __FUNCTION__, device, quiet ? "true" : "false" );
   uint8_t command[] = { ERASE_CMD };
   uint8_t length = 1;
@@ -315,7 +315,7 @@ int32_t stm32_erase_flash( dfu_device_t *device, dfu_bool quiet ) {
 }
 
 int32_t stm32_page_erase( dfu_device_t *device, uint32_t address,
-                           dfu_bool quiet ) {
+                           bool quiet ) {
   TRACE( "%s( %p, 0x%X, %s )\n", __FUNCTION__, device, address,
       quiet ? "true" : "false" );
   uint8_t length = 5;
@@ -331,7 +331,7 @@ int32_t stm32_page_erase( dfu_device_t *device, uint32_t address,
   return stm32_erase( device, command, length, quiet );
 }
 
-int32_t stm32_start_app( dfu_device_t *device, dfu_bool quiet ) {
+int32_t stm32_start_app( dfu_device_t *device, bool quiet ) {
   TRACE( "%s( %p )\n", __FUNCTION__, device );
   int32_t status;
 
@@ -348,7 +348,7 @@ int32_t stm32_start_app( dfu_device_t *device, dfu_bool quiet ) {
   }
 
   if( !quiet ) fprintf( stderr, "Launching program...  \n" );
-  dfu_set_transaction_num( 0 );     /* set wValue to zero */
+  dfu_set_transaction_num( device, 0 );     /* set wValue to zero */
   if( 0 != dfu_download(device, 0, NULL) ) {
     if( !quiet ) fprintf( stderr, "ERROR\n" );
     DEBUG( "dfu_download failed\n" );
@@ -365,7 +365,7 @@ int32_t stm32_start_app( dfu_device_t *device, dfu_bool quiet ) {
 }
 
 int32_t stm32_read_flash( dfu_device_t *device, intel_buffer_in_t *buin,
-    const uint8_t mem_segment, const dfu_bool quiet ) {
+    const uint8_t mem_segment, const bool quiet ) {
   TRACE( "%s( %p, %p, %u, %s )\n", __FUNCTION__, device, buin,
       mem_segment, ((true == quiet) ? "true" : "false"));
 
@@ -411,7 +411,7 @@ int32_t stm32_read_flash( dfu_device_t *device, intel_buffer_in_t *buin,
         retval = UNSPECIFIED_ERROR;
         goto finally;
       }
-      dfu_set_transaction_num( 2 ); /* sets block offset 0 */
+      dfu_set_transaction_num( device, 2 ); /* sets block offset 0 */
       reset_address_flag = 0;
     }
 
@@ -441,7 +441,7 @@ int32_t stm32_read_flash( dfu_device_t *device, intel_buffer_in_t *buin,
 
     buin->info.block_start = buin->info.block_end + 1;
     if( reset_address_flag == 0 && (buin->info.block_start !=
-        (STM32_MAX_TRANSFER_SIZE * (dfu_get_transaction_num() - 2))
+        (STM32_MAX_TRANSFER_SIZE * (dfu_get_transaction_num( device ) - 2))
         + address_offset) ) {
       DEBUG("block start & address mismatch, reset req\n");
       reset_address_flag = 1;
@@ -475,7 +475,7 @@ finally:
 }
 
 int32_t stm32_write_flash( dfu_device_t *device, intel_buffer_out_t *bout,
-    const dfu_bool eeprom, const dfu_bool force, const dfu_bool quiet ) {
+    const bool eeprom, const bool force, const bool quiet ) {
   TRACE( "%s( %p, %p, %s, %s )\n", __FUNCTION__, device, bout,
           ((true == eeprom) ? "true" : "false"),
           ((true == quiet) ? "true" : "false") );
@@ -581,7 +581,7 @@ int32_t stm32_write_flash( dfu_device_t *device, intel_buffer_out_t *bout,
         retval = DEVICE_ACCESS_ERROR;
         goto finally;
       }
-      dfu_set_transaction_num( 2 ); /* sets block offset 0 */
+      dfu_set_transaction_num( device, 2 ); /* sets block offset 0 */
       reset_address_flag = 0;
     }
 
@@ -626,7 +626,7 @@ int32_t stm32_write_flash( dfu_device_t *device, intel_buffer_out_t *bout,
     } // bout->info.block_start is now on the first valid data for the next segment
 
     if( reset_address_flag == 0 && (bout->info.block_start !=
-        (STM32_MAX_TRANSFER_SIZE * (dfu_get_transaction_num() - 2))
+        (STM32_MAX_TRANSFER_SIZE * (dfu_get_transaction_num( device ) - 2))
         + address_offset) ) {
       DEBUG("block start does not match addr, reset req\n");
       reset_address_flag = 1;
@@ -674,7 +674,7 @@ int32_t stm32_get_commands( dfu_device_t *device ) {
     return UNSPECIFIED_ERROR;
   }
 
-  dfu_set_transaction_num( 0 );
+  dfu_set_transaction_num( device, 0 );
   result = dfu_upload( device, xfer_len, buffer );
   if( result < 0) {
     dfu_status_t status;
@@ -736,7 +736,7 @@ int32_t stm32_get_configuration( dfu_device_t *device ) {
   return SUCCESS;
 }
 
-int32_t stm32_read_unprotect( dfu_device_t *device, dfu_bool quiet ) {
+int32_t stm32_read_unprotect( dfu_device_t *device, bool quiet ) {
   TRACE( "%s( %p, %s )\n", __FUNCTION__, device, quiet ? "true" : "false" );
   uint8_t command[] = { READ_UNPROTECT };
   uint8_t length = 1;
