@@ -23,7 +23,7 @@
 
 #include "util.h"
 
-extern int debug;       /* defined in main.c */
+extern int debug;       /* defined in libdfu.c */
 
 void dfu_debug( const char *file, const char *function, const int line,
                 const int level, const char *format, ... )
